@@ -5,7 +5,7 @@ import singer
 from google.oauth2 import service_account
 from google.cloud import bigquery
 from singer import metadata
-from macrometa_source_bigquery.sync_bigquery import _build_query, row_to_singer_record, should_sync_column
+from macrometa_source_bigquery.sync_bigquery import _build_query, row_to_dict_singer_record, should_sync_column
 
 
 def fetch_table(conn_info, stream):
@@ -37,7 +37,7 @@ def fetch_table(conn_info, stream):
     extract_tstamp = datetime.datetime.utcnow()
     extract_tstamp = extract_tstamp.replace(tzinfo=datetime.timezone.utc)
     for row in query_job:
-        record = row_to_singer_record(row, properties, extract_tstamp)
+        record = row_to_dict_singer_record(row, properties, extract_tstamp)
         rec_msg = singer.RecordMessage(
             stream=stream['stream'],
             record=record,
