@@ -257,8 +257,56 @@ def row_to_singer_record(row, properties, extract_tstamp):
     return record
 
 
+def row_to_dict_singer_record(row, properties, extract_tstamp):
+    record = {}
+    for key in properties.keys():
+        prop = properties[key]
+
+        if key in [LEGACY_TIMESTAMP,
+                   EXTRACT_TIMESTAMP,
+                   BATCH_TIMESTAMP]:
+            continue
+        LOGGER.info("Row key %s", row[key])
+        if row[key] is None:
+            if prop['type'][0] != "null":
+                raise ValueError(
+                    "NULL value not allowed by the schema"
+                )
+            else:
+                record[key] = None
+        elif prop.get('format') == "date-time":
+            if type(row[key]) == str:
+                r = dateutil.parser.parse(row[key])
+            elif type(row[key]) == datetime.date:
+                r = datetime.datetime(
+                    year=row[key].year,
+                    month=row[key].month,
+                    day=row[key].day)
+            elif type(row[key]) == datetime.datetime:
+                r = row[key]
+            record[key] = r.isoformat()
+        elif prop['type'][1] == "string":
+            record[key] = str(row[key])
+        elif prop['type'][1] == "number":
+            record[key] = Decimal(row[key])
+        elif prop['type'][1] == "integer":
+            record[key] = int(row[key])
+        else:
+            record[key] = row[key]
+
+    if LEGACY_TIMESTAMP in properties.keys():
+        record[LEGACY_TIMESTAMP] = int(round(time.time() * 1000))
+    if EXTRACT_TIMESTAMP in properties.keys():
+        record[EXTRACT_TIMESTAMP] = extract_tstamp.isoformat()
+
+    LOGGER.info("Record at end of function %s", record)
+    return record
+
+
 def should_sync_column(md_map, field_name):
+    LOGGER.info("Entering should_sync_column %s", field_name)
     field_metadata = md_map.get(('properties', field_name), {})
+    LOGGER.info("Debugging 12 %s", field_metadata)
     return singer.should_sync_field(field_metadata.get('inclusion'),
                                     field_metadata.get('selected'),
                                     True)
